/*
 * Copyright (c) 2008, Koji Tsukada<tsuka@mobiquitous.com> 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution.
 *    
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
 * IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED 
 * OF THE POSSIBILITY OF SUCH DAMAGE.
*/
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;

using System.Text.RegularExpressions;

namespace MobiServer.Devices
{
    public partial class ControlBase : UserControl
    {
        string label = "";
        string device = "";
        protected const string SETTING_DIR = "setting"; 

        public event MobiServer.ReadHandler serverReadHandler;
        public event MobiServer.WriteHandler serverWriteHandler;
        public event MobiServer.MessageHandler messageHandler;

        public MobiServer.TCPServer serverControl;
        public MobiServer.Message messageControl;

        public ControlBase(string device, string label)
        {
            InitializeComponent();
            this.device = device;
            this.label = label;
            this.groupBox1.Text = label;
        }

        public ControlBase(string device, string label, MobiServer.TCPServer server, MobiServer.Message message)
        {
            InitializeComponent();
            this.device = device;
            this.label = label;
            this.serverControl = server;
            this.messageControl = message;
            this.messageHandler += new MobiServer.MessageHandler(this.messageControl.OnMessageEvent);
            this.groupBox1.Text = label;
        }
        

        public ControlBase()
        {
            InitializeComponent();
        }


        public bool CheckLabel(string label)
        {
            Match m = Regex.Match(this.label, label, RegexOptions.IgnoreCase);

            if (m.Success)
                return true;
            else
                return false;
        }

        public string Label
        {
            get { return label;}
        }

        public virtual void OnServerReadEvent(object sender, MobiServer.ServerEventArgs e)
        {
           
        }

        protected void CreateServerWriteEvent(string[] args)
        {
            MobiServer.ServerEventArgs e = new MobiServer.ServerEventArgs(args);
            serverWriteHandler(this, e);
        }

        public virtual void SaveSetting()
        {

        }

        public virtual void LoadSetting()
        {

        }

        #region Message Events

        public void PrintError(string m, params object[] args)
        {
            MobiServer.MessageEventArgs e = new MobiServer.MessageEventArgs(String.Format(m, args), MobiServer.States.Error);

            if (messageHandler != null)
                messageHandler(this, e);
        }


        public void PrintMessage(string m, params object[] args)
        {
            MobiServer.MessageEventArgs e = new MobiServer.MessageEventArgs(String.Format(m, args));

            if (messageHandler != null)
                messageHandler(this, e);

            return;
        }

        public void PrintDebug(string m, params object[] args)
        {
            MobiServer.MessageEventArgs e = new MobiServer.MessageEventArgs(String.Format(m, args), MobiServer.States.Debug);

            if (messageHandler != null)
                messageHandler(this, e);
        }

        #endregion


    }
}
